@@ -484,8 +484,10 @@ class AppHandler(object):
            the app.
         """
         if not hasattr(self, 'email_handler'):
-            from rattail.mail import get_email_handler
-            self.email_handler = get_email_handler(self.config, **kwargs)
+            spec = self.config.get('rattail', 'email.handler',
+                                   default='rattail.mail:EmailHandler')
+            Handler = self.load_object(spec)
+            self.email_handler = Handler(self.config, **kwargs)
         return self.email_handler
 
     def get_mail_handler(self, **kwargs): # pragma: no cover
