@@ -79,7 +79,10 @@ class FromCSVToSQLAlchemyMixin(object):
         mapper = orm.class_mapper(cls)
         fields = list(mapper.columns.keys())
         pkeys = get_primary_keys(cls)
-        return type('{}Importer'.format(name), (FromCSV, self.ToParent), {
+        name = '{}Importer'.format(name)
+        if six.PY2:
+            name = name.encode('utf_8')
+        return type(name, (FromCSV, self.ToParent), {
             'model_class': cls,
             'supported_fields': fields,
             'simple_fields': fields,
