@@ -36,7 +36,6 @@ import logging
 import six
 
 from rattail.daemon import Daemon
-from rattail.db import api
 from rattail.mailmon.config import load_mailmon_profiles
 from rattail.mailmon.util import (get_lastrun,
                                   get_lastrun_setting,
@@ -245,8 +244,11 @@ class IMAPAccountWatcher(object):
                     else:
                         # poll went okay, so record last run time
                         setting = get_lastrun_setting(self.config, profile.key)
-                        api.save_setting(None, setting,
-                                         now.strftime(self.lastrun_timefmt))
+                        session = self.app.make_session()
+                        self.app.save_setting(session, setting,
+                                              now.strftime(self.lastrun_timefmt))
+                        session.commit()
+                        session.close()
                         lastruns[profile.key] = now
 
             # maybe pause for a tick on account of error
